@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE OverloadedStrings #-}
 module Web.Cookie
     ( -- * Server to client
@@ -19,12 +20,14 @@ module Web.Cookie
       -- ** Functions
     , parseSetCookie
     , renderSetCookie
+    , renderSetCookieBS
     , defaultSetCookie
     , def
       -- * Client to server
     , Cookies
     , parseCookies
     , renderCookies
+    , renderCookiesBS
       -- ** UTF8 Version
     , CookiesText
     , parseCookiesText
@@ -37,10 +40,13 @@ module Web.Cookie
 
 import qualified Data.ByteString as S
 import qualified Data.ByteString.Char8 as S8
+import qualified Data.ByteString.Lazy as L
 import Data.Char (toLower, isDigit)
-import Data.ByteString.Builder (Builder, byteString, char8)
+import Data.ByteString.Builder (Builder, byteString, char8, toLazyByteString)
 import Data.ByteString.Builder.Extra (byteStringCopy)
+#if !(MIN_VERSION_base(4,8,0))
 import Data.Monoid (mempty, mappend, mconcat)
+#endif
 import Data.Word (Word8)
 import Data.Ratio (numerator, denominator)
 import Data.Time (UTCTime (UTCTime), toGregorian, fromGregorian, formatTime, parseTimeM, defaultTimeLocale)
@@ -101,6 +107,10 @@ renderCookie (k, v) = k `mappend` char8 '=' `mappend` v
 renderCookies :: Cookies -> Builder
 renderCookies = renderCookiesBuilder . map (byteString *** byteString)
 
+-- | @since 0.4.6
+renderCookiesBS :: Cookies -> S.ByteString
+renderCookiesBS = L.toStrict . toLazyByteString . renderCookies
+
 -- | Data type representing the key-value pair to use for a cookie, as well as configuration options for it.
 --
 -- ==== Creating a SetCookie
@@ -223,6 +233,10 @@ renderSetCookie sc = mconcat
         Just None -> byteStringCopy "; SameSite=None"
     ]
 
+-- | @since 0.4.6
+renderSetCookieBS :: SetCookie -> S.ByteString
+renderSetCookieBS = L.toStrict . toLazyByteString . renderSetCookie
+
 parseSetCookie :: S.ByteString -> SetCookie
 parseSetCookie a = SetCookie
     { setCookieName = name
