@@ -55,7 +55,7 @@ instance Arbitrary Char' where
     arbitrary = fmap (Char' . toEnum) $ choose (62, 125)
 newtype SameSiteOption' = SameSiteOption' { unSameSiteOption' :: SameSiteOption }
 instance Arbitrary SameSiteOption' where
-  arbitrary = fmap SameSiteOption' (elements [sameSiteLax, sameSiteStrict])
+  arbitrary = fmap SameSiteOption' (elements [sameSiteLax, sameSiteStrict, sameSiteNone])
 
 propParseRenderSetCookie :: SetCookie -> Bool
 propParseRenderSetCookie sc =
